@@ -67,11 +67,11 @@ class Client(MFPBase):
             return name
         return self.ABBREVIATIONS[name]
 
-    def _get_url_for_date(self, date):
+    def _get_url_for_date(self, date, username):
         return os.path.join(
             self.BASE_URL,
             'food/diary',
-            self.username,
+            username,
         ) + '?date=%s' % (
             date.strftime('%Y-%m-%d')
         )
@@ -143,7 +143,15 @@ class Client(MFPBase):
                 if not this.attrib.get('class') is None:
                     break
                 columns = this.findall('td')
-                name = columns[0].find('a').text
+
+                # When viewing a friend's diary, the HTML entries containing the
+                # actual food log entries are different: they don't contain an
+                # embedded <a/> element but rather the food name directly.
+                if columns[0].find('a') is None:
+                    name = columns[0].text.strip()
+                else:
+                    name = columns[0].find('a').text
+
                 nutrition = {}
 
                 for n in range(1, len(columns)):
@@ -175,7 +183,7 @@ class Client(MFPBase):
 
         return meals
 
-    def get_date(self, *args):
+    def get_date(self, *args, **kwargs):
         if len(args) == 3:
             date = datetime.date(
                 int(args[0]),
@@ -192,7 +200,8 @@ class Client(MFPBase):
             )
         document = self._get_document_for_url(
             self._get_url_for_date(
-                date
+                date,
+                kwargs.get('username', self.username)
             )
         )
 
